#[non_exhaustive]pub enum SegmentFault {
Empty,
Dot,
Char(char),
}Expand description
Why a path segment cannot be a literal URL segment.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The segment is empty.
Dot
The segment is . or ...
Char(char)
The segment holds a character a route segment cannot.