pub async fn render_notification<'a>(
cx: &'a Cx,
notification: Notification,
attrs: Attributes,
) -> Result<BoxView<'a>>Expand description
Renders one notification as the toast, with attrs merged onto its surface.
pub async fn render_notification<'a>(
cx: &'a Cx,
notification: Notification,
attrs: Attributes,
) -> Result<BoxView<'a>>Renders one notification as the toast, with attrs merged onto its surface.