pub struct RowActions {
pub view: Option<String>,
pub edit: Option<String>,
pub delete_href: Option<String>,
pub delete_action: Option<String>,
}Expand description
The action targets of one row.
Fields
view: Option<String>The View link target, None when policy hides it.
edit: Option<String>The Edit link target, None when policy hides it.
delete_href: Option<String>The Delete link target, None when policy hides it.
delete_action: Option<String>The Delete POST target carried by data-row-delete-action.