#[non_exhaustive]pub enum Site {
Panel,
Registration,
Tenancy,
Table,
Form,
View,
Relation(String),
}Expand description
The part of a declaration a DeclarationError is in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Panel
The panel’s own configuration: its prefix, served directories, assets and auth.
Registration
The resource or page itself: its registration, slug, actions or create columns, or a second home page.
Tenancy
ResourceDef::tenancy.
Table
ResourceDef::table.
Form
ResourceDef::form, checked against the record form.
View
ResourceDef::view.
Relation(String)
The ResourceDef::relation to the resource with this slug, or this type when the panel
does not register it.