pub struct LiveToasterPropsBuilder<__status = status, __title = title, __description = description, __serial = serial> { /* private fields */ }Expand description
Typestate builder for LiveToasterProps, created by LiveToasterProps::builder(). build() becomes available once every required property has been set.
Implementations
Sourceimpl<__status, __title, __description, __serial> LiveToasterPropsBuilder<__status, __title, __description, __serial>
impl<__status, __title, __description, __serial> LiveToasterPropsBuilder<__status, __title, __description, __serial>
Sourcepub fn status(
self,
status: impl Into<Expr<Signal<String>>>,
) -> LiveToasterPropsBuilder<Set, __title, __description, __serial>
pub fn status( self, status: impl Into<Expr<Signal<String>>>, ) -> LiveToasterPropsBuilder<Set, __title, __description, __serial>
Sets the status property.
Sourcepub fn title(
self,
title: impl Into<Expr<Signal<String>>>,
) -> LiveToasterPropsBuilder<__status, Set, __description, __serial>
pub fn title( self, title: impl Into<Expr<Signal<String>>>, ) -> LiveToasterPropsBuilder<__status, Set, __description, __serial>
Sets the title property.
Sourcepub fn description(
self,
description: impl Into<Expr<Signal<String>>>,
) -> LiveToasterPropsBuilder<__status, __title, Set, __serial>
pub fn description( self, description: impl Into<Expr<Signal<String>>>, ) -> LiveToasterPropsBuilder<__status, __title, Set, __serial>
Sets the description property.
Sourcepub fn serial(
self,
serial: impl Into<Expr<Signal<u64>>>,
) -> LiveToasterPropsBuilder<__status, __title, __description, Set>
pub fn serial( self, serial: impl Into<Expr<Signal<u64>>>, ) -> LiveToasterPropsBuilder<__status, __title, __description, Set>
Sets the serial property.
Sourcepub fn build(self) -> LiveToasterProps
pub fn build(self) -> LiveToasterProps
Builds the props struct from the set properties.
Only available once every required property has been set.
#[default] properties that were not set are filled with
Default::default(), or the #[default(expr)] expression.